LorMe package summarizes a series of functions normally used in microbiome analysis analysis.
Wang Ningqi
_PACKAGE
#Basic functions####
auto_signif_test Automatically conduct significance testing
compare_plot Comparison plot generator
Filter_function Filter OTU/ASV/metagenomic profile/gene profile by threshold
tax_summary Encapsulate meta file, feature tables and taxonomy annotation into tax summary object
sub_tax_summary subsets tax summary objects according to meta file
combine_and_translate Combine feature table with meta file and transform into a recognizable data frame for visualization.
color_scheme generate color scheme from nine color scheme database and expand into colorRamp
theme_zg A classic theme for ggplot.
#Community features####
Alpha_diversity_calculator Calculator for alpha diversity of each sample.
Dimension_reduction Dimension reduction analysis including PCA,PCOA and NMDS
structure_plot A fast view of microbial structure with PCA plot,PCOA plot and NMDS plot.
Top_taxa Calculate most abundant taxon
community_plot A fast view of microbial community with bar plot,alluvial plot and area plot.
#Differential analysis####
Deseq_analysis Performs a differential expression analysis
indicator_analysis Performs the indicator analysis based on taxonomic summary object
differential_bar Generate Differential Bar Plot and errorbar plot
volcano_plot Generate volcano plot base on Deseq_analysis or indicator_analysis results
manhattan Generate Manhattan Plot base on Deseq_analysis or indicator_analysis results
#Network analysis####
network_analysis A convenient and fast network analysis function, with output results suitable for cytoscape and gephi
network_withdiff Meta network analysis integrating differential taxon into a network analysis
network_visual Visualizes a network based on network object from network_analysis
network_visual_re Re-visualize or adjust network plot from network_visual or network_withdiff
Module_composition Pie chart for network module composition
Module_abundance Calculate network module abundance for each sample
nc Calculate network Natural Connectivity
NC_remove Conduct natural connectivity analysis
#Correlation analysis####
circulation_lm Quick test using circulation to fit linear models between one dependent variable and series of independent variable
tbRDA_analysis RDA analysis including co-linearity diagnostics and necessary statistics.