View source: R/sub_tax_summary.R
| sub_tax_summary | R Documentation |
Subsetting tax summary objects
sub_tax_summary(taxobj, ..., specificnum = NULL, taxnum = NULL)
taxobj |
tax summary objects computed by |
... |
logical expression that are are defined in terms of the variables in Groupfile of tax summary objects. See details in |
specificnum |
specific numbers indicating samples to keep based on Groupfile of tax summary objects. |
taxnum |
specific numbers indicating taxonomy to keep based on Base file |
Subset of tax summary objects.Same as tax_summary.
Wang Ningqi 2434066068@qq.com
data("Three_group")
# Check meta file
print(Three_group$groupfile)
# Subsetting tax summary objects
# Select BF and OF groups
sub_testtax_summary <- sub_tax_summary(Three_group, Group %in% c("BF", "OF"))
print(sub_testtax_summary$groupfile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.