View source: R/Trans_from_microeco.R
| Trans_from_microeco | R Documentation |
Convert a microeco object to a LorMe object
Trans_from_microeco(
microtab,
into = "standard",
outputtax = c("Phylum", "Genus"),
reads = TRUE
)
microtab |
A |
into |
Names of separated taxonomy to create as character vector. Must select from c("Domain","Phylum","Class","Order","Family","Genus","Species"). Shortcut input:1)By default."standard":c("Domain","Phylum","Class","Order","Family","Genus","Species"). Used for standard taxonomy annotation to OTU/ASV table. 2)"complete":c("Domain","Kingdom","Phylum","Class","Order","Family","Genus","Species"). Used for complete taxonomy annotation to meta genomic table. |
outputtax |
Default:c("Phylum","Genus").Names of output taxonomy level table. Shortcut input is available with 'standard' and 'complete' same as above. |
reads |
Logical.True for reads table and FALSE for percentage table. Default: TRUE |
LorMe object containing taxonomy table data frame,containing reads and percentage table for each specified output.
For taxonomy annotation with both 'Domain' and 'Kingdom' level, please set 'into' parameter as 'complete'!!!
## Not run:
if (requireNamespace("microeco", quietly = TRUE)) {
data("dataset", package = "microeco")
## convert microeco object to LorMe format
dataset_obj <- Trans_from_microeco(dataset, outputtax = "standard")
## specify experimental design
dataset_obj_plan <- object_config(dataset_obj,
treat_location = 4)
## generate community-structure PCoA plot (Genus level)
community_structure <- structure_plot(dataset_obj_plan, taxlevel = "Genus")
community_structure$PCoA_Plot
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.